@@ -1,22 +1,20 @@
 from cv2 import namedWindow
+
 from .cli import ArgParser
 from .debug_utils import cCOLOURS, debug_show
 from .image import WarpedImage
-from .pdf import save_pdf
 from .options import cfg
-
+from .pdf import save_pdf
 
 # for some reason pylint complains about cv2 members being undefined :(
 # pylint: disable=E1101
 
-WINDOW_NAME = "Dewarp"  # Window name for visualization
-
 
 def main():
     parser = ArgParser()
 
     if cfg.debug_lvl_opt.DEBUG_LEVEL > 0 and cfg.debug_out_opt.DEBUG_OUTPUT != "file":
-        namedWindow(WINDOW_NAME)
+        namedWindow("Dewarp")
 
     outfiles = []
 
